@@ -208,12 +208,12 @@ func (mlrmap *Mlrmap) findEntry(key string) *MlrmapEntry {
 // findEntryByPositionalIndex is for '$[1]' etc. in the DSL.
 //
 // Notes:
-// * This is a linear search.
-// * Indices are 1-up not 0-up
-// * Indices -n..-1 are aliases for 1..n. In particular, it will be faster to
-//   get the -1st field than the nth.
-// * Returns 0 on invalid index: 0, or < -n, or > n where n is the number of
-//   fields.
+//   - This is a linear search.
+//   - Indices are 1-up not 0-up
+//   - Indices -n..-1 are aliases for 1..n. In particular, it will be faster to
+//     get the -1st field than the nth.
+//   - Returns 0 on invalid index: 0, or < -n, or > n where n is the number of
+//     fields.
 func (mlrmap *Mlrmap) findEntryByPositionalIndex(position int64) *MlrmapEntry {
 	if position > mlrmap.FieldCount || position < -mlrmap.FieldCount || position == 0 {
 		return nil
@@ -339,7 +339,7 @@ func (mlrmap *Mlrmap) getWithMlrvalArrayIndex(index *Mlrval) (*Mlrval, error) {
 	current := mlrmap
 	var retval *Mlrval = nil
 	lib.InternalCodingErrorIf(!index.IsArray())
-	array := index.arrayval
+	array := index.intf.([]*Mlrval)
 	n := len(array)
 	for i, piece := range array {
 		next, err := current.GetWithMlrvalIndex(piece)
@@ -350,7 +350,7 @@ func (mlrmap *Mlrmap) getWithMlrvalArrayIndex(index *Mlrval) (*Mlrval, error) {
 			if !next.IsMap() {
 				return nil, fmt.Errorf("mlr: cannot multi-index non-map.")
 			}
-			current = next.mapval
+			current = next.intf.(*Mlrmap)
 		} else {
 			retval = next.Copy()
 		}
@@ -782,11 +782,11 @@ func (mlrmap *Mlrmap) SortByKeyRecursively() {
 
 	for _, key := range keys {
 		// Old record will be GC'ed: just move pointers
-		value := mlrmap.Get(key)
-		if value.IsMap() {
-			value.mapval.SortByKeyRecursively()
+		val := mlrmap.Get(key)
+		if val.IsMap() {
+			val.intf.(*Mlrmap).SortByKeyRecursively()
 		}
-		other.PutReference(key, value)
+		other.PutReference(key, val)
 	}
 
 	*mlrmap = *other
