@@ -18,6 +18,8 @@ type RecordWriterCSV struct {
 	lastJoinedHeader *string
 	// Only write one blank line for schema changes / blank input lines
 	justWroteEmptyLine bool
+	// For double-quote around all fields
+	quoteAll bool
 }
 
 func NewRecordWriterCSV(writerOptions *cli.TWriterOptions) (*RecordWriterCSV, error) {
@@ -32,6 +34,7 @@ func NewRecordWriterCSV(writerOptions *cli.TWriterOptions) (*RecordWriterCSV, er
 		csvWriter:          nil, // will be set on first Write() wherein we have the output stream
 		lastJoinedHeader:   nil,
 		justWroteEmptyLine: false,
+		quoteAll:           writerOptions.CSVQuoteAll,
 	}, nil
 }
 
@@ -81,7 +84,7 @@ func (writer *RecordWriterCSV) Write(
 			i++
 		}
 		//////writer.csvWriter.Write(fields)
-		writer.WriteCSVRecordMaybeColorized(fields, bufferedOutputStream, outputIsStdout, true)
+		writer.WriteCSVRecordMaybeColorized(fields, bufferedOutputStream, outputIsStdout, true, writer.quoteAll)
 	}
 
 	fields := make([]string, outrec.FieldCount)
@@ -90,6 +93,6 @@ func (writer *RecordWriterCSV) Write(
 		fields[i] = pe.Value.String()
 		i++
 	}
-	writer.WriteCSVRecordMaybeColorized(fields, bufferedOutputStream, outputIsStdout, false)
+	writer.WriteCSVRecordMaybeColorized(fields, bufferedOutputStream, outputIsStdout, false, writer.quoteAll)
 	writer.justWroteEmptyLine = false
 }
